from pathlib import Path
from halo import Halo
from os import rmdir
import tibis.lib.logger as log
import tibis.lib.common as common
import tibis.lib.config as config
import tibis.lib.static as static

def lock(dirname):
	if(config.isEncrypting()):
		log.error("Wait for previous operation to end")
	else:
		if(not common.existsInDB(dirname)):
			log.error("Directory not in database")
			return False
		if(not common.isUnlocked(dirname)):
			log.error("Directory is already locked")
			return False
		else:
			#Get Keys
			publicKeyLocation=common.getPublicKey(dirname)
			mountPoint=common.getMountPoint(dirname)
			if(not Path(static.tibis_tmp_dir).exists()):
				path = Path(static.tibis_tmp_dir)
				path.mkdir(parents=True,exist_ok=True)
			if(publicKeyLocation):
				#Create archive
				config.defineEncryptingStatus(True)
				#Empty the tmpdir
				[f.unlink() for f in Path(static.tibis_tmp_dir).glob("*") if f.is_file()]
				#Create the archive
				spinner = Halo(text='Creating archive ',spinner='moon')
				spinner.start()
				archivePath=common.createArchive(dirname,mountPoint,static.tibis_tmp_dir)
				spinner.succeed('Archive created')
				if(config.check_integrity_status()):
					spinner = Halo(text='Checking directory integrity ',spinner='moon')
					spinner.start()
					directoryIntegrity=common.calculate_directory_hash(mountPoint)
					spinner.succeed('Directory integrity obtained')
					spinner = Halo(text='Checking archive integrity ',spinner='moon')
					spinner.start()
					archiveIntegrity=common.checkArchiveIntegrity(str(archivePath))
					spinner.succeed('Archive integrity obtained')
					common.checkIntegrityIsOK(archiveIntegrity,directoryIntegrity,mountPoint)

				spinner = Halo(text='Encrypting and moving',spinner='moon')
				spinner.start()
				isCrypted=common.cryptArchive(publicKeyLocation,archivePath,config.storage_path(),dirname)
				spinner.succeed('Archive encrypted')
				#Need To check the previous return status
				if(isCrypted):
					spinner = Halo(text='Removing files ',spinner='moon')
					spinner.start()
					[f.unlink() for f in Path(static.tibis_tmp_dir).glob("*") if f.is_file()]
					common.remove_dir(mountPoint)
					common.updateStatus(dirname,'locked')
					common.updateMountPoint(dirname,'')
					spinner.succeed('Files removed')
					log.success(dirname+" is locked")
					config.defineEncryptingStatus(False)
				else:
					log.error("Something went wrong ...")
 
if __name__ == '__main__':
    lock(dirname)



import pgpy
import sqlite3
import getpass
import tibis.lib.common as common
import tibis.lib.config as config
import tibis.lib.static as static
import tibis.lib.logger as log
from halo import Halo
from pathlib import Path
from tibis.lib.common import getPrivateKey

def unlock(dirname,destination):
 #Verifier que c'est pas déja unlock
 if(not common.existsInDB(dirname)):
  log.error("Directory not in database")
  return False
 if(common.isUnlocked(dirname)):
  log.error("Already unlocked")
  return False
 else:
  #GetKey
  enc_privatekey, _ = pgpy.PGPKey.from_file(static.tibis_keys_location+"/"+dirname+"/private")
  #Unlock key
  log.ask("Enter passphrase :")
  p = getpass.getpass("")

  try:
    spinner = Halo(text='Unlocking passphrase', spinner='moon')
    spinner.start()
    with enc_privatekey.unlock(p) as privatekey:
        #Uncrypt datas
        encrypted_content=pgpy.PGPMessage.from_file(config.storage_path()+"/"+dirname)
        plaintext=privatekey.decrypt(encrypted_content).message
        spinner.succeed('unlocked')
        #TODO Verify if its ok
        #Empty tmp dir
        spinner = Halo(text='Cleaning tmp dir', spinner='moon')
        spinner.start()
        [f.unlink() for f in Path(static.tibis_tmp_dir).glob("*") if f.is_file()]
        spinner.succeed('tmp dir cleaned')
        with open(static.tibis_tmp_dir+"/"+dirname,'wb') as archive:
            archive.write(plaintext)

        #Prepare output
        path=Path(destination)
        path.mkdir(exist_ok=True,parents=True)
        spinner = Halo(text='Uncompressing datas', spinner='moon')
        spinner.start()
        common.uncompressArchive(static.tibis_tmp_dir+"/"+dirname,destination)
        spinner.succeed('Datas Uncompressed')
        if(common.updateStatus(dirname,"unlocked") and common.updateMountPoint(dirname,destination)):
            log.success("Open at "+destination)
        spinner = Halo(text='Cleaning tmp dir', spinner='moon')
        spinner.start()
        [f.unlink() for f in Path(static.tibis_tmp_dir).glob("*") if f.is_file()]
        spinner.succeed('tmp dir cleaned')
        
        #Print warning for opened container
        unlockedCount=0
        db=static.tibis_db_location
        conn=sqlite3.connect(db)
        cursor_obj = conn.cursor()
        sql = static.tibis_database_list_all
        cursor_obj.execute(sql)
        rows = cursor_obj.fetchall()
        for row in rows:
            name=row[0]
            status=row[3]
            mount_point=row[4]
            if(status=='unlocked'):
                unlockedCount+=1
            
        if(unlockedCount>1):
            log.warning(f"You have {unlockedCount} container unlocked !")
            log.warning("Remember to have as less unencrypted data as possible.")
  except Exception as e:
    log.error(e)
  finally:
    conn.close()

if __name__ == '__main__':
    unlock(dirname,destination)



import yaml 
import tibis.lib.static as static
import sys

def storage_path():
    with open(static.tibis_full_config_location) as file:
        p = yaml.load(file,Loader=yaml.FullLoader)
        return p['storage_path']

def pgp_infos():
    with open(static.tibis_full_config_location) as file:
        p = yaml.load(file,Loader=yaml.FullLoader)
        return p['pgp_infos']

def check_integrity_status():
    with open(static.tibis_full_config_location) as file:
        p = yaml.load(file,Loader=yaml.FullLoader)
        if('check_integrity' in p ):
            return p['check_integrity']
        else:
            return True
def compression_method():
    with open(static.tibis_full_config_location) as file:
        p = yaml.load(file,Loader=yaml.FullLoader)
        if('compression_method' in p):
            return p['compression_method']
        else:
            return 'gz'

def isEncrypting():
    with open(static.tibis_full_config_location) as file:
        p = yaml.load(file,Loader=yaml.FullLoader)
        if('encrypting' in p):
            return p['encrypting']
        else:
            return False

def defineEncryptingStatus(status):
    with open(static.tibis_full_config_location,'r+') as file:
        p = yaml.load(file,Loader=yaml.FullLoader)
        p['encrypting']=status
        yaml.dump(p,file)


import simple_chalk as chalk
from halo import Halo
from log_symbols import LogSymbols


def info(text):
 spinner=Halo()
 spinner.info(text)

def success(text):
 spinner=Halo()
 spinner.succeed(text)

def ask(text):
 spinner=Halo()
 spinner.warn(text)

def warning(text):
 spinner=Halo()
 spinner.warn(text)

def error(text):
 spinner=Halo()
 spinner.fail(text)

def locked(text):
 spinner=Halo()
 toPrint = "[LOCKED] : "+text
 print(chalk.green.bold(toPrint))

def unlocked(text):
 spinner=Halo()
 toPrint="[ OPEN ] : "+text
 print(chalk.red.bold(toPrint))